@@ -1,4 +1,4 @@
-# Copyright (C) 2019-2021 Clémence Frioux & Arnaud Belcour - Inria Dyliss - Pleiade
+# Copyright (C) 2019-2022 Clémence Frioux & Arnaud Belcour - Inria Dyliss - Pleiade
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -63,6 +63,10 @@ def gbk_creation(nucleic_fasta:str, protein_fasta:str, annot:str,
     elif all(types[input_file] == 'directory' for input_file in types if input_file != annot) and types[annot] == 'file':
         directory_mode = True
         one_annot_file = True
+    elif any(input_file is None for input_file in types.values()):
+        missing_files = [input_file for input_file in types if types[input_file] is None]
+        logger.critical(f"Missing input file or folder : "+' '.join(missing_files))
+        sys.exit(1)
     else:
         logger.critical(f"Invalid combinations of input, three are possible: all inputs (nucleic fasta, protein fasta, annotation, [gff]) are files, all inputs are directories or annotation is file and the other inputs are directories.")
         sys.exit(1)
